@@ -17,9 +17,15 @@ from click_default_group import DefaultGroup
 
 from .build import build, push
 from .manage import path_cmd, output, list_cmd, enable
+from . import __version__
 
 
-@click.group(cls=DefaultGroup, default="output", default_if_no_args=True)
+@click.group(
+    cls=DefaultGroup,
+    default="output",
+    default_if_no_args=True,
+)
+@click.version_option(__version__)
 def cli():
     pass
 
